Index: main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/sample_document_data.csv
===================================================================
--- main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/sample_document_data.csv	(revision 11997)
+++ main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/sample_document_data.csv	(revision 12004)
@@ -1,3 +1,3 @@
-id,reg_number,title
+document_id,reg_number,title
 d1266236341953,1,My first doc
 d1266236341954,2,My second doc
Index: main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_document.py
===================================================================
--- main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_document.py	(revision 11997)
+++ main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_document.py	(revision 12004)
@@ -1,3 +1,3 @@
-## $Id: tests.py 9469 2012-10-30 17:49:17Z henrik $
+## $Id$
 ##
 ## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
@@ -57,7 +57,7 @@
         container = CustomerDocumentsContainer()
         document = createObject(u'waeup.CustomerDocument')
-        document.id = 'my_document'
+        id = document.document_id
         container.addDocument(document)
-        self.assertEqual(container['my_document'], document)
+        self.assertEqual(container[id], document)
         self.assertRaises(TypeError, container.addDocument, object())
         return

Index: main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_batching.py
===================================================================
--- main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_batching.py	(revision 11997)
+++ main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_batching.py	(revision 12004)
@@ -1,4 +1,4 @@
 # -*- coding: utf-8 -*-
-## $Id: test_batching.py 11756 2014-07-09 12:46:08Z henrik $
+## $Id$
 ##
 ## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
@@ -259,6 +259,6 @@
         self.customer = self.app['customers'][customer.customer_id]
         document = createObject(u'waeup.CustomerDocument')
-        document.id = 'd120'
-        self.customer['documents'][document.id] = document
+        document.document_id = 'd120'
+        self.customer['documents'][document.document_id] = document
 
         # Import customers with subobjects
@@ -282,19 +282,19 @@
     def test_getEntry(self):
         assert self.processor.getEntry(
-            dict(customer_id='ID_NONE', id='nonsense'), self.app) is None
-        assert self.processor.getEntry(
-            dict(customer_id=self.customer.customer_id, id='d120'),
+            dict(customer_id='ID_NONE', document_id='nonsense'), self.app) is None
+        assert self.processor.getEntry(
+            dict(customer_id=self.customer.customer_id, document_id='d120'),
             self.app) is self.customer['documents']['d120']
 
     def test_delEntry(self):
         assert self.processor.getEntry(
-            dict(customer_id=self.customer.customer_id, id='d120'),
+            dict(customer_id=self.customer.customer_id, document_id='d120'),
             self.app) is self.customer['documents']['d120']
         self.assertEqual(len(self.customer['documents'].keys()),1)
         self.processor.delEntry(
-            dict(customer_id=self.customer.customer_id, id='d120'),
+            dict(customer_id=self.customer.customer_id, document_id='d120'),
             self.app)
         assert self.processor.getEntry(
-            dict(customer_id=self.customer.customer_id, id='d120'),
+            dict(customer_id=self.customer.customer_id, document_id='d120'),
             self.app) is None
         self.assertEqual(len(self.customer['documents'].keys()),0)
@@ -303,24 +303,24 @@
         self.assertEqual(len(self.customer['documents'].keys()),1)
         document1 = createObject(u'waeup.CustomerDocument')
-        document1.id = 'p234'
+        document1.document_id = 'p234'
         self.processor.addEntry(
-            document1, dict(customer_id=self.customer.customer_id, id='p234'),
+            document1, dict(customer_id=self.customer.customer_id, document_id='p234'),
             self.app)
         self.assertEqual(len(self.customer['documents'].keys()),2)
-        self.assertEqual(self.customer['documents']['p234'].id, 'p234')
+        self.assertEqual(self.customer['documents']['p234'].document_id, 'p234')
         document2 = createObject(u'waeup.CustomerDocument')
-        document1.id = 'nonsense'
+        document1.document_id = 'nonsense'
 
     def test_checkConversion(self):
         errs, inv_errs, conv_dict = self.processor.checkConversion(
-            dict(id='d1266236341955'))
+            dict(document_id='d1266236341955'))
         self.assertEqual(len(errs),0)
         errs, inv_errs, conv_dict = self.processor.checkConversion(
-            dict(id='nonsense'))
+            dict(document_id='nonsense'))
         self.assertEqual(len(errs),1)
         timestamp = ("%d" % int(time()*10000))[1:]
-        id = "d%s" % timestamp
-        errs, inv_errs, conv_dict = self.processor.checkConversion(
-            dict(id=id))
+        document_id = "d%s" % timestamp
+        errs, inv_errs, conv_dict = self.processor.checkConversion(
+            dict(document_id=document_id))
         self.assertEqual(len(errs),0)
 
@@ -330,11 +330,11 @@
         self.assertEqual(num_warns,0)
         document = self.processor.getEntry(dict(reg_number='1',
-            id='d1266236341953'), self.app)
+            document_id='d1266236341953'), self.app)
         self.assertEqual(
             self.app['customers']['X666666']['documents']['d1266236341953'],
             document)
-        self.assertEqual(document.id, 'd1266236341953')
+        self.assertEqual(document.document_id, 'd1266236341953')
         document = self.processor.getEntry(dict(reg_number='3',
-            id='d1266236341955'), self.app)
+            document_id='d1266236341955'), self.app)
         shutil.rmtree(os.path.dirname(fin_file))
         logcontent = open(self.logfile).read()
@@ -343,5 +343,5 @@
             'INFO - system - CustomerDocument Processor - '
             'sample_document_data - X666666 - updated: '
-            'id=d1266236341953, title=My first doc'
+            'document_id=d1266236341953, title=My first doc'
             in logcontent)
 
@@ -355,5 +355,5 @@
         num, num_warns, fin_file, fail_file = self.processor.doImport(
             self.csv_file, DOCUMENT_HEADER_FIELDS,'update')
-        self.assertEqual(num_warns,1)  # There is one record without id
+        self.assertEqual(num_warns,1)  # There is one record without document_id
         shutil.rmtree(os.path.dirname(fin_file))
 
@@ -367,5 +367,5 @@
         num, num_warns, fin_file, fail_file = self.processor.doImport(
             self.csv_file, DOCUMENT_HEADER_FIELDS,'remove')
-        self.assertEqual(num_warns,1)  # There is one record without id
+        self.assertEqual(num_warns,1)  # There is one record without document_id
         shutil.rmtree(os.path.dirname(fin_file))
         logcontent = open(self.logfile).read()